@@ -1,18 +1,17 @@
 import threading
 from logging import Logger
 
-from blinker import Signal
+from blinker import signal
 
 from sidecar.app_instance_config_status_event_reporter import AppInstanceConfigStatusEventReporter
 from sidecar.app_instance_identifier import AppInstanceIdentifier
 from sidecar.app_instance_service import IAppInstanceService
 from sidecar.apps_configuration_end_tracker import AppsConfigurationEndTracker
+from sidecar.const import Signals
 from sidecar.sandbox_deployment_state_tracker import SandboxDeploymentStateTracker
 
 
 class AppStatusMaintainer:
-    on_instance_update_status = Signal()
-
     def __init__(self, logger: Logger,
                  app_instance_service: IAppInstanceService,
                  apps_configuration_end_tracker: AppsConfigurationEndTracker,
@@ -25,7 +24,7 @@ class AppStatusMaintainer:
         self._app_instance_config_status_event_reporter = app_instance_status_event_reporter
         self._lock = threading.RLock()
 
-    def update_status(self, app_instance_identifier: AppInstanceIdentifier, status: str, script_name: str):
+    def update_status(self, app_instance_identifier: AppInstanceIdentifier, status: str):
         # we want to report the event even if the instance is stale, so doing it before update_status_if_not_stale
         # the event handling should be able to handle concurrency so calling it outside the lock
         self._safely_report_app_instance_event(app_instance_identifier, status)
@@ -68,7 +67,8 @@ class AppStatusMaintainer:
                 app_instance_identifier=app_instance_identifier,
                 app_instance_config_status=status)
 
-        self.on_instance_update_status.send(self, identifier=app_instance_identifier, script_name=script_name)
+        signal(Signals.ON_INSTANCE_UPDATE_STATUS)\
+            .send(self, identifier=app_instance_identifier)
 
     def _safely_report_app_instance_event(self, app_instance_identifier: AppInstanceIdentifier, status: str):
         # don't want unhandled errors in event handling to ruin the rest of the flow
