@@ -5,8 +5,8 @@ from typing import Dict, List
 
 from sidecar.app_instance_identifier import AppInstanceIdentifier
 from sidecar.app_instance_service import IAppInstanceService
-from sidecar.app_request_info import AppRequestInfo
 from sidecar.const import AppInstanceConfigStatus
+from sidecar.model.objects import SidecarApplication
 
 
 class AppConfigurationEndStatus:
@@ -67,13 +67,19 @@ class AppRecord:
         del self.instance_config_end_statuses[app_instance_identifier.infra_id]
 
 
+class IAppInstanceRetriever(object):
+    pass
+
+
 class AppsConfigurationEndTracker:
-    def __init__(self, logger: Logger, app_requests: List[AppRequestInfo],
+    def __init__(self, logger: Logger,
+                 apps: List[SidecarApplication],
                  app_instance_service: IAppInstanceService):
-        self._logger = logger
         self._app_instance_service = app_instance_service
+        self._logger = logger
+        self._apps = apps
         self._lock = threading.RLock()
-        self._app_records = self._build_app_records(app_requests, logger)
+        self._app_records = self._build_app_records(apps)
 
     def update_app_instance_config_status(self, app_instance_identifier: AppInstanceIdentifier,
                                           app_instance_config_status: str):
@@ -103,7 +109,7 @@ class AppsConfigurationEndTracker:
             return app_statuses
 
     @staticmethod
-    def _build_app_records(app_requests: List[AppRequestInfo], logger: Logger) -> Dict[str, AppRecord]:
+    def _build_app_records(app_requests: List[SidecarApplication]) -> Dict[str, AppRecord]:
         app_records = {app_request.name: AppRecord(app_name=app_request.name,
                                                    expected_instances_count=app_request.instances_count)
                        for app_request in app_requests}
