@@ -44,15 +44,6 @@ class AwsSandboxStartTimeUpdater(ISandboxStartTimeUpdater):
     def _update_sidecar_start_time(self):
         self.aws_status_maintainer.update_sandbox_start_status(self._date_time_provider.get_current_time_utc())
 
-    @staticmethod
-    def _update_stack(self, stack_name: str):
-        stack = self._cf.Stack(stack_name)
-        time = str(self._date_time_provider.get_current_time_utc())
-        stack.update(
-            UsePreviousTemplate=True,
-            Tags=[AwsTagHelper.create_tag(Const.SANDBOX_START_TIME, time),
-                  AwsTagHelper.create_tag(Const.SANDBOX_START_TIME_v2, time)])
-
     @staticmethod
     def _get_side_car_instance_id():
         response = requests.get('http://169.254.169.254/latest/meta-data/instance-id')
