@@ -33,6 +33,7 @@ class AwsSession:
 
         self.ec2_resource = self._get_resource('ec2', self._config)
         self._autoscalling_client = self._get_client('autoscaling', self._config)
+        self._elb_client = self._get_client('elb', self._config)
         self.cloudwatch_client = self._get_client('logs', self._config)
 
 
@@ -54,6 +55,9 @@ class AwsSession:
     def get_autoscaling_client(self):
         return self._autoscalling_client
 
+    def get_elb_client(self):
+        return self._elb_client
+
     def _get_client(self, client: str, config: Config):
         return self.session.client(client, region_name=self._region_name, config=config)
 
