@@ -49,7 +49,7 @@ class AWSStatusMaintainer:
         table = self.dynamo_resource.Table(self.default_table_name)
 
         try:
-            Utils.wait_for(func=lambda:  self._set_table_data(table, sandbox_id) is not None,
+            Utils.wait_for(func=lambda: self._set_table_data(table, sandbox_id) is not None,
                            interval_sec=1,
                            max_retries=5,
                            error='No sandbox data available')
@@ -73,16 +73,20 @@ class AWSStatusMaintainer:
         return None
 
     def update_app_instance_status(self, instance_logical_id, instance_id, app_name, status_tag, status):
-
-        table = self.dynamo_resource.Table(self.default_table_name)
-        if instance_id not in self.table_data["apps"][instance_logical_id]["instances"]:
-            self.table_data["apps"][instance_logical_id]["instances"][instance_id] = \
-                {
-                    "apps": {}
-                }
+        try:
+            if instance_id not in self.table_data["apps"][instance_logical_id]["instances"]:
+                self.table_data["apps"][instance_logical_id]["instances"][instance_id] = \
+                    {
+                        "apps": {}
+                    }
+        except Exception as ex:  # log details for debugging, related to bug #1689
+            self._logger.exception('fail to update instance status. instance_logical_id: {}, table_data: {}, exc={}'
+                                   .format(instance_logical_id, self.table_data, str(ex)))
+            raise ex
 
         self.table_data["apps"][instance_logical_id]["instances"][instance_id]["apps"][app_name] = {status_tag: status}
 
+        table = self.dynamo_resource.Table(self.default_table_name)
         response = table.update_item(
             Key={
                 Const.SANDBOX_ID_TAG: self.sandboxid
@@ -95,9 +99,10 @@ class AWSStatusMaintainer:
         )
 
         if self.response_failed(response):
-            self._logger.error("Error update_app_instance_status(sandbox_id: {sandbox_id}. app_name: {app}. instance_id: {instance_id})\n"
-                               "Response: {data}"
-                               .format(sandbox_id=self.sandboxid, app=app_name, instance_id= instance_id, data=response))
+            self._logger.error(
+                "Error update_app_instance_status(sandbox_id: {sandbox_id}. app_name: {app}. instance_id: {instance_id})\n"
+                "Response: {data}"
+                .format(sandbox_id=self.sandboxid, app=app_name, instance_id=instance_id, data=response))
 
     def update_sandbox_end_status(self, sandbox_deployment_end_status: str):
         table = self.dynamo_resource.Table(self.default_table_name)
