@@ -4,21 +4,21 @@ from inspect import getmembers, isclass, isabstract
 from logging import Logger
 
 from sidecar.aws_session import AwsSession
+from sidecar.model.objects import ISidecarConfiguration
 from .. import cloud_logger
 from . import ICloudLogger, FileLogger
 
 
 class CloudLoggerFactory(object):
-    def __init__(self, config: dict, logger: Logger, logger_session: AwsSession, file_logger: FileLogger):
+    def __init__(self, config: ISidecarConfiguration, logger: Logger, logger_session: AwsSession, file_logger: FileLogger):
         self.config = config
         self.logger = logger
         self.cloud_logger = None
         self.logger_session = logger_session
         self.file_logger = file_logger
 
-        provider = config["provider"]
         for path, pkg_name, is_package in pkgutil.iter_modules(cloud_logger.__path__):
-            if is_package and pkg_name == provider:
+            if is_package and pkg_name == config.provider:
                 pkg = importlib.import_module(".{}".format(pkg_name), package=cloud_logger.__name__)
                 classes = getmembers(pkg, lambda m: isclass(m) and not isabstract(m) and issubclass(m, ICloudLogger))
                 if len(classes) > 0:
@@ -29,4 +29,4 @@ class CloudLoggerFactory(object):
         if self.cloud_logger is not None:
             return self.cloud_logger(self.config, self.logger, self.logger_session, self.file_logger)
         else:
-            return FileLogger(self.config)
+            return self.file_logger
