@@ -4,11 +4,12 @@ from abc import ABC, abstractmethod
 
 
 class LogEntry(object):
-    def __init__(self, app: str, instance: str, topic: str, log_events: List[Tuple[datetime, str]]):
+    def __init__(self, app: str, instance: str, topic: str, log_events: List[Tuple[datetime, str]], log_type: str):
         self.app = app
         self.instance = instance
         self.topic = topic
         self.log_events = log_events
+        self.log_type = log_type
 
     def get_as_string(self) -> str:
         log_events_str = "\n".join(str(time) + " " + message for time, message in self.log_events)
