@@ -3,6 +3,11 @@ import os
 from os.path import expanduser
 
 
+class Signals:
+    ON_INSTANCE_UPDATE_STATUS = "ON_INSTANCE_UPDATE_STATUS"
+    ON_APPS_DEPLOYMENT_COMPLETE = "ON_APPS_DEPLOYMENT_COMPLETE"
+
+
 class AppNetworkStatus:
     PENDING = "pending"
     TESTING_PUBLIC_NETWORK = "testing_public_network"
@@ -50,12 +55,12 @@ def get_app_selector(app_name: str):
 
 
 class Const:
+    EXTERNAL_ELB_DNS_NAME = _get_tag_name('external-elb-dsn')
     APP_STATE_KEY_VALUE_SEPARATOR = ":"
     APP_NAME_TAG = _get_tag_name('app-name')
     APP_STATUS_TAG = _get_tag_name('app-status')
     APPS = _get_tag_name('apps')
     HEALTH_CHECK_STATUS = _get_tag_name("health-check-status")
-    EXTERNAL_ELB_DNS_NAME = _get_tag_name('external-elb-dsn')
     SANDBOX_ID_TAG = _get_tag_name('sandbox-id')
     SANDBOX_START_TIME = 'start-time'
     SANDBOX_START_TIME_v2 = _get_tag_name('start-time')
@@ -67,9 +72,9 @@ class Const:
     K8S_SIDECAR_SERVICE = 'sidecar-service'
     K8S_SIDECAR_APP_SELECTOR = get_app_selector(K8S_SIDECAR_SERVICE)
 
-    AWS_SIDECAR_APP_NAME = 'crumb'
+    AWS_SIDECAR_APP_NAME = 'colonySidecar'
 
-    QUALY_SERVICE_NAME = 'qualiY'
+    QUALY_SERVICE_NAME = 'colonyDebugService'
 
     SIDECAR_HOME_FOLDER = os.path.join(expanduser("~"), 'sidecar')
 
