@@ -3,19 +3,21 @@ import os
 import platform
 import socket
 
+from sidecar.model.objects import ISidecarConfiguration
+
 
 class LoggingFilter(logging.Filter):
-    def __init__(self, config_json):
+    def __init__(self, config: ISidecarConfiguration):
         logging.Filter.__init__(self)
-        self.config_json = config_json
+        self.config = config
 
     def filter(self, record: logging.LogRecord):
         record.__dict__['colony.application'] = 'sidecar'
         record.__dict__['colony.branch'] = os.getenv('branch', "none")
-        record.__dict__['colony.environment'] = self.config_json['environment']
+        record.__dict__['colony.environment'] = self.config.environment
         record.__dict__['colony.hostname'] = self._get_hostname()
         record.__dict__['colony.level'] = record.levelname
-        record.__dict__['colony.sandbox_id'] = self.config_json['sandbox_id']
+        record.__dict__['colony.sandbox_id'] = self.config.sandbox_id
         record.__dict__['colony.threadId'] = record.thread
         record.logger = '{0} {1}'.format(record.filename, record.funcName)
         return record
