@@ -2,15 +2,13 @@ import threading
 from logging import Logger
 from typing import List, Dict
 
-from blinker import Signal
+from blinker import signal
 
-from sidecar.const import AppNetworkStatus
+from sidecar.const import AppNetworkStatus, Signals
 from sidecar.utils import CallsLogger
 
 
 class AppHealthCheckState:
-    on_apps_deployment_complete = Signal()
-
     def __init__(self, app_names: List[str], logger: Logger):
         self._lock = threading.RLock()
         self._logger = logger
@@ -26,7 +24,7 @@ class AppHealthCheckState:
                                     in self._app_states.values())
 
         if all_apps_complete:
-            self.on_apps_deployment_complete.send(self)
+            signal(Signals.ON_APPS_DEPLOYMENT_COMPLETE).send(self)
 
     @CallsLogger.wrap
     def all_complete_with_success(self) -> bool:
