@@ -26,39 +26,33 @@ class AppInstanceHealthCheckMonitor:
         self._logger = logger
 
     @CallsLogger.wrap
-    def start(self, address: str, identifier: IIdentifier, script_name: str):
-        thread = threading.Thread(target=self.process_health_check, args=(address, identifier, script_name))
+    def start(self, address: str, identifier: IIdentifier):
+        thread = threading.Thread(target=self.process_health_check, args=(address, identifier))
         thread.start()
 
-    def process_health_check(self, ip_address: str, identifier: AppInstanceIdentifier, script_name: str):
+    def process_health_check(self, ip_address: str, identifier: AppInstanceIdentifier):
         try:
             status = AppInstanceConfigStatus.PENDING
             self._status_maintainer.update_status(app_instance_identifier=identifier,
-                                                  status=status,
-                                                  script_name=script_name)
+                                                  status=status)
 
             result = self._execute_health_check_script(identifier=identifier,
-                                                       ip_address=ip_address,
-                                                       script_name=script_name)
+                                                       ip_address=ip_address)
 
             status = AppInstanceConfigStatus.COMPLETED if result else AppInstanceConfigStatus.ERROR
             self._status_maintainer.update_status(app_instance_identifier=identifier,
-                                                  status=status,
-                                                  script_name=script_name)
+                                                  status=status)
         except Exception as ex:
-            self._logger.exception("error - identifier: '{}', ip: '{}', script: '{}'. {}".format(
+            self._logger.exception("error - identifier: '{}', ip: '{}'. {}".format(
                 identifier,
                 ip_address,
-                script_name,
                 str(ex)))
             raise
 
     def _execute_health_check_script(self,
                                      identifier,
-                                     ip_address: str,
-                                     script_name: str) -> bool:
+                                     ip_address: str) -> bool:
         cmd = self._preparer.prepare(app_name=identifier.name,
-                                     script_name=script_name,
                                      address=ip_address)
 
         return self._executor.start(identifier=identifier,
