@@ -3,10 +3,11 @@ import signal
 import subprocess
 from datetime import datetime
 from logging import Logger
-from typing import List, Dict
+from typing import List
 
 from sidecar.app_instance_identifier import IIdentifier
 from sidecar.health_check.health_check_executor_logger import HealthCheckExecutorLogger
+from sidecar.model.objects import SidecarApplication
 from sidecar.non_blocking_stream_reader import NonBlockingStreamReader
 from sidecar.utils import CallsLogger
 
@@ -14,29 +15,30 @@ from sidecar.utils import CallsLogger
 class HealthCheckExecutor:
 
     def __init__(self,
-                 env_vars: Dict[str, str],
-                 app_timeouts: Dict[str, int],
+                 apps: List[SidecarApplication],
                  executor_logger: HealthCheckExecutorLogger,
                  logger: Logger):
+        self._apps = apps
         self._executor_logger = executor_logger
-        self._app_timeouts = app_timeouts
-        self._env_vars = env_vars
         self._logger = logger
 
     @CallsLogger.wrap
     def start(self, identifier: IIdentifier, cmd: List[str]) -> bool:
-        timeout = self._app_timeouts.get(identifier.name)
-        self._executor_logger.log_start(identifier=identifier, cmd=cmd, timeout=timeout)
 
-        env = self._get_env_vars(identifier)
+        app = next(iter([app for app in self._apps if app.name == identifier.name]), None)  # type: SidecarApplication
+
+        self._executor_logger.log_start(identifier=identifier, cmd=cmd, timeout=app.healthcheck_timeout)
+        env = {**os.environ, **app.env}
 
         start = datetime.now()
         timed_out = False
         read_interval = 0.5
-
-        # run healthcheck command in subprocess and redirect its outputs to subprocess' stdout
-        # read stdout line by line until subprocess ended or until timeout and send it to cloud logger
-        # if timeout occurred kill healthcheck subprocess
+        
+        """
+        run healthcheck command in subprocess and redirect its outputs to subprocess' stdout
+        read stdout line by line until subprocess ended or until timeout and send it to cloud logger
+        if timeout occurred kill healthcheck subprocess
+        """
         with subprocess.Popen(cmd,
                               stdout=subprocess.PIPE,
                               stderr=subprocess.PIPE,
@@ -60,10 +62,10 @@ class HealthCheckExecutor:
 
                     elapsed = datetime.now() - start
 
-                    if elapsed.total_seconds() > timeout:
+                    if elapsed.total_seconds() > app.healthcheck_timeout:
                         stdout_stream_reader.stop()
                         stderr_stream_reader.stop()
-                        raise subprocess.TimeoutExpired(cmd=cmd, timeout=timeout)
+                        raise subprocess.TimeoutExpired(cmd=cmd, timeout=app.healthcheck_timeout)
 
                     if p.poll() is not None:
                         while True:
@@ -84,7 +86,7 @@ class HealthCheckExecutor:
                         break
             except subprocess.TimeoutExpired as ex:
                 self._executor_logger.log_timeout(timeout=ex.timeout, identifier=identifier)
-                self._kill_process(identifier=identifier, process=p)
+                self._kill_process(process=p)
                 timed_out = True
             finally:
                 if timed_out:
@@ -97,16 +99,10 @@ class HealthCheckExecutor:
                     self._executor_logger.log_error(identifier=identifier, exit_code=process_exit_code)
                     return False
 
-    def _kill_process(self, identifier, process):
+    def _kill_process(self, process):
         try:
             os.killpg(os.getpgid(process.pid), signal.SIGTERM)
         except ProcessLookupError as ex:
             self._logger.exception('Could not kill process, pid {} due to {}'.format(
                 process.pid,
                 str(ex)))
-
-    def _get_env_vars(self, identifier):
-        # get process environment variables and mix them with user defined application specific environment
-        # variables
-        app_env = self._env_vars.get(identifier.name)
-        return {**os.environ, **({} if app_env is None else app_env)}
