@@ -50,21 +50,11 @@ class AppInstanceHealthCheckExecutorLogger(HealthCheckExecutorLogger):
             cmd,
             timeout)
 
-        log_entry = LogEntry(app_instance_identifier.name,
-                             app_instance_identifier.infra_id,
-                             HEALTH_CHECK_TOPIC,
-                             [(datetime.utcnow(),
-                               line)], "HealthCheck")
-
-        self.cloud_logger.write(log_entry)
-        self.logger.info(log_entry.get_as_string())
+        self._log(line, app_instance_identifier)
 
     def log_line(self, line: str, identifier: AppInstanceIdentifier, error: bool = False):
         app_instance_identifier = identifier
-        log_entry = LogEntry(app_instance_identifier.name,
-                             app_instance_identifier.infra_id,
-                             HEALTH_CHECK_TOPIC,
-                             [(datetime.utcnow(), line)], "HealthCheck")
+        log_entry = self._create_log_entry(app_instance_identifier, line)
 
         self.cloud_logger.write(log_entry)
 
@@ -84,12 +74,16 @@ class AppInstanceHealthCheckExecutorLogger(HealthCheckExecutorLogger):
         self._log(line=line, app_instance_identifier=app_instance_identifier)
 
     def _log(self, line: str, app_instance_identifier: AppInstanceIdentifier):
+        log_entry = self._create_log_entry(app_instance_identifier, line)
+        self.logger.info(log_entry.get_as_string())
+        self.cloud_logger.write(log_entry)
+
+    def _create_log_entry(self, app_instance_identifier, line):
         log_entry = LogEntry(app_instance_identifier.name, app_instance_identifier.infra_id,
                              HEALTH_CHECK_TOPIC,
                              [(datetime.utcnow(),
                                line)], "HealthCheck")
-        self.logger.info(log_entry.get_as_string())
-        self.cloud_logger.write(log_entry)
+        return log_entry
 
 
 class AppHealthCheckExecutorLogger(HealthCheckExecutorLogger):
@@ -110,20 +104,7 @@ class AppHealthCheckExecutorLogger(HealthCheckExecutorLogger):
         self.logger.info(log_entry.get_as_string())
 
     def log_line(self, line: str, identifier, error: bool = False):
-        identifier = identifier  # type: AppIdentifier
-        log_entry = LogEntry(identifier.name,
-                             "app",
-                             HEALTH_CHECK_TOPIC,
-                             [(datetime.utcnow(), line)], "HealthCheck")
-
-        if error:
-            self.logger.info("stdout - identifier: '{}', line: '{}'".format(
-                identifier,
-                log_entry.get_as_string()))
-        else:
-            self.logger.error("stderr - identifier: '{}', line: '{}'".format(
-                identifier,
-                log_entry.get_as_string()))
+        pass
 
     def log_timeout(self, timeout: int, identifier: IIdentifier):
         identifier = identifier  # type: AppIdentifier
