@@ -3,6 +3,8 @@ import pika
 from logging import Logger
 from jsonpickle import json
 
+from sidecar.utils import CallsLogger
+
 
 class MessagingConnectionProperties:
     def __init__(self, host: str,
@@ -14,7 +16,7 @@ class MessagingConnectionProperties:
                  virtualhost: str,
                  port: int,
                  queuetype: str,
-                 expires,
+                 expires: int,
                  usessl: bool):
         self.host = host
         self.user = user
@@ -28,6 +30,42 @@ class MessagingConnectionProperties:
         self.expires = expires
         self.usessl = usessl
 
+    def __eq__(self, other):
+        if isinstance(self, other.__class__):
+            return self.host == other.host and \
+                   self.password == other.password and \
+                   self.queue == other.queue and \
+                   self.exchange == other.exchange and \
+                   self.routingkey == other.routingkey and \
+                   self.virtualhost == other.virtualhost and \
+                   self.port == other.port and \
+                   self.queuetype == other.queuetype and \
+                   self.expires == other.expires and \
+                   self.usessl == other.usessl
+        return False
+
+    def __repr__(self):
+        return "host={} " \
+               "password={} " \
+               "queue={} " \
+               "exchange={} " \
+               "routingkey={} " \
+               "virtualhost={} " \
+               "port={} " \
+               "queuetype={} " \
+               "expires={} " \
+               "usessl={}".format(self.host,
+                                  self.password,
+                                  self.queue,
+                                  self.exchange,
+                                  self.routingkey,
+                                  self.virtualhost,
+                                  self.port,
+                                  self.queuetype,
+                                  self.expires,
+                                  self.usessl)
+
+
 class MessagingService:
     def __init__(self, connection_props: MessagingConnectionProperties, logger: Logger):
         self._connection = None
@@ -47,6 +85,7 @@ class MessagingService:
                                                                       virtual_host=connection_props.virtualhost)
         self.endpoint = connection_props.queue
 
+    @CallsLogger.wrap
     def publish(self, message_type: str, message):
         try:
             message_id = uuid.uuid1()
