@@ -4,28 +4,24 @@ from logging import Logger
 from typing import List
 
 from sidecar.app_instance_identifier import AppInstanceIdentifier
-from sidecar.app_request_info import AppRequestInfo
 from sidecar.apps_configuration_end_tracker import AppsConfigurationEndTracker, AppConfigurationEndStatus
 from sidecar.const import AppInstanceConfigStatus, SandboxDeploymentEndStatus
+from sidecar.model.objects import SidecarApplication
 from sidecar.sandbox_deployment_end_updater import ISandboxDeploymentEndUpdater
-from sidecar.messaging_service import MessagingService
 
 
 class SandboxDeploymentStateTracker:
-    def __init__(self, logger: Logger, app_requests: List[AppRequestInfo],
+    def __init__(self, logger: Logger,
+                 apps: List[SidecarApplication],
                  apps_configuration_end_tracker: AppsConfigurationEndTracker,
                  sandbox_deployment_end_updater: ISandboxDeploymentEndUpdater,
-                 sandbox_id,
-                 space_id: str
-                 ):
+                 space_id: str):
         self._logger = logger
         self._apps_configuration_end_tracker = apps_configuration_end_tracker
         self._sandbox_deployment_end_updater = sandbox_deployment_end_updater
-        self._app_deployment_end_statuses = {app_request.name: None for app_request in app_requests}
-        self._remaining_app_config_counts = {app_request.name: app_request.instances_count * 2
-                                             for app_request in app_requests}
+        self._app_deployment_end_statuses = {app.name: None for app in apps}
+        self._remaining_app_config_counts = {app.name: app.instances_count * 2 for app in apps}
         self._deployment_end_status = None
-        self._sandbox_id = sandbox_id
         self.space_id = space_id
 
         self._lock = threading.RLock()
@@ -91,7 +87,6 @@ class SandboxDeploymentStateTracker:
                               .format(END_STATUS=end_status))
             self._sandbox_deployment_end_updater.on_sandbox_deployment_ended(deployment_end_status=end_status)
 
-
     @staticmethod
     def _is_app_deployment_ended_with_status(actual_end_status: str, required_app_status: str) -> bool:
         return actual_end_status is not None and actual_end_status == required_app_status
