@@ -1,13 +1,12 @@
+import datetime
 import inspect
 import logging
-import os
 import sys
-
-import time
-
-import datetime
 from logging import Logger
 
+import requests
+import time
+
 from sidecar.const import Const
 
 
@@ -50,19 +49,47 @@ class Utils:
                            logger: Logger = None,
                            logger_msg: str = "",
                            interval: int = 1,
-                           timeout: int = 10):
-        remains = timeout / interval
+                           timeout_in_sec: int = 10):
+        start = datetime.datetime.now()
+        attempt_number = 1
         while True:
             try:
-                return func()
-            except Exception as e:
-                if remains == 0:
-                    raise e
-                else:
+                res = func()
+                if attempt_number > 1:
                     if logger:
-                        logger.info("{} ({} remaining attempts)".format(logger_msg, remains))
-                remains -= 1
+                        elapsed = datetime.datetime.now() - start
+                        logger.info(
+                            "{} (succeed after {}s with {} attempts)".format(logger_msg, elapsed.total_seconds(),
+                                                                             attempt_number))
+                return res
+            except requests.exceptions.ConnectionError as ce:
+                if "Failed to establish a new connection: [Errno -2] Name or service not known'" in str(ce):
+                    logger.exception(str(ce))
+                    logger.fatal("logger shut down, no access to cloud provider.")
+                    Utils._reset_logger()
+                    raise ce
+                Utils._handle_exception(attempt_number, ce, logger, logger_msg, start, timeout_in_sec)
+            except Exception as e:
+                Utils._handle_exception(attempt_number, e, logger, logger_msg, start, timeout_in_sec)
+            finally:
                 time.sleep(interval)
+            attempt_number += 1
+
+    @staticmethod
+    def _handle_exception(attempt_number, ce, logger, logger_msg, start, timeout_in_sec):
+        elapsed = datetime.datetime.now() - start
+        in_seconds = elapsed.total_seconds()
+        if in_seconds > timeout_in_sec:
+            if logger:
+                logger.info("Failure while {} (timed out after {}s with {} attempts)"
+                            .format(logger_msg, in_seconds, attempt_number))
+            raise ce
+
+    @staticmethod
+    def _reset_logger():
+        for handler in logging.root.handlers[:]:
+            logging.root.removeHandler(handler)
+        logging.basicConfig()
 
 
 class CallsLogger:
@@ -81,8 +108,9 @@ class CallsLogger:
             args_list = ["{}: '{}'".format(k, v) for (k, v) in bound_args.arguments.items()]
             if len(bound_args.arguments) > 0 and bound_args.arguments.get('self'):
                 args_list = args_list[1:]
-
-            cls.logger.info(func.__qualname__ + "(" + ", ".join(args_list) + ")")
+            if cls.logger:
+                cls.logger.info(func.__qualname__ + "(" + ", ".join(args_list) + ")")
 
             return func(**bound_args.arguments)
+
         return decorator
